@@ -117,11 +117,11 @@ plot_PriorPost.fitTK <- function(x, select = "all", ...){
   
   df$group <- paste0(df$parameter, df$type)
   
-  ggplot(data = df, aes_string('value')) + 
+  ggplot(data = df, aes(.data[['value']])) + 
     theme_classic() +
     scale_fill_manual(values = c("orange", "grey")) +
     scale_x_log10() +
-    geom_density(aes_string(group = 'group', fill = 'type'), alpha = 0.5, color = NA) +
+    geom_density(aes(group = .data[['group']], fill = .data[['type']]), alpha = 0.5, color = NA) +
     facet_wrap(~parameter, scales = "free")
   
 }
@@ -146,11 +146,11 @@ plot_PriorPost.df_PP <- function(x, select = "all", ...){
   
   df$group <- paste0(df$parameter, df$type)
   
-  ggplot(data = df, aes_string('value')) + 
+  ggplot(data = df, aes(.data[['value']])) + 
     theme_classic() +
     scale_fill_manual(values = c("orange", "grey")) +
     scale_x_log10() +
-    geom_density(aes_string(group = 'group', fill = 'type'), alpha = 0.5, color = NA) +
+    geom_density(aes(group = .data[['group']], fill = .data[['type']]), alpha = 0.5, color = NA) +
     facet_wrap(~parameter, scales = "free")
   
 }
\ No newline at end of file
