@@ -22,7 +22,7 @@ plot_exposure <- function(object){
 
   plt <- ggplot(data = df) + 
     theme_classic() +
-    geom_line(aes_string(x = 'time', y = 'exposure')) +
+    geom_line(aes(x = .data[['time']], y = .data[['exposure']])) +
     facet_wrap(~route, scales = "free")
   
   return(plt)
