@@ -32,9 +32,9 @@ plot.fitTK <- function(x, time_interp = NULL, ...){
       labs(x = "Time", y = "Concentration") +
       # scale_y_continuous(limits = c(0,NA)) +
       geom_ribbon(
-        aes_string(x = 'time', ymin = 'qinf95', ymax = 'qsup95'), fill = "grey80") +
-      geom_line(aes_string(x = 'time', y = 'q50'), color = "orange") +
-      geom_point(aes_string(x = 'time', y = 'observation' )) + 
+        aes(x = .data[['time']], ymin = .data[['qinf95']], ymax = .data[['qsup95']]), fill = "grey80") +
+      geom_line(aes(x = .data[['time']], y = .data[['q50']]), color = "orange") +
+      geom_point(aes(x = .data[['time']], y = .data[['observation']])) + 
       facet_wrap(~variable, scales = "free")
     
     return(plt)
