@@ -28,8 +28,8 @@ plot.predictTK <- function(x, ...){
     labs(x = "Time", y = "Concentration") +
     # scale_y_continuous(limits = c(0,NA)) +
     geom_ribbon(
-      aes_string(x = 'time', ymin = 'qinf95', ymax = 'qsup95'), fill = "grey80") +
-    geom_line(aes_string(x = 'time', y = 'q50'), color = "orange") +
+      aes(x = .data[['time']], ymin = .data[['qinf95']], ymax = .data[['qsup95']]), fill = "grey80") +
+    geom_line(aes(x = .data[['time']], y = .data[['q50']]), color = "orange") +
     facet_wrap(~variable, scales = "free")
   
   return(plt)
@@ -59,8 +59,8 @@ plot.predictTKstan <- function(x, add_data=FALSE, ...){
     labs(x = "Time", y = "Concentration") +
     # scale_y_continuous(limits = c(0,NA)) +
     geom_ribbon(
-      aes_string(x = 'time', ymin = 'qinf95', ymax = 'qsup95'), fill = "grey80") +
-    geom_line(aes_string(x = 'time', y = 'q50'), color = "orange") +
+      aes(x = .data[['time']], ymin = .data[['qinf95']], ymax = .data[['qsup95']]), fill = "grey80") +
+    geom_line(aes(x = .data[['time']], y = .data[['q50']]), color = "orange") +
     facet_wrap(~variable, scales = "free")
 
   if(add_data == TRUE){
@@ -74,7 +74,7 @@ plot.predictTKstan <- function(x, add_data=FALSE, ...){
     
     plt <- plt +  geom_point(
       data = df_data,
-      aes_string(x = 'time', y = 'observation' ))
+      aes(x = .data[['time']], y = .data[['observation']]))
   }
   
   return(plt)
