@@ -17,10 +17,10 @@ test_that("mcmcTraces", {
   plt_MGSG_sto <- mcmcTraces(fit_MGSG,"stochastic")
   
   # Check class
-  expect_true(all(class(plt_MGS) == c("gg", "ggplot")))
-  expect_true(all(class(plt_MGS_det) == c("gg", "ggplot")))
-  expect_true(all(class(plt_MGS_sto) == c("gg", "ggplot")))
-  expect_true(all(class(plt_MGSG) == c("gg", "ggplot")))
-  expect_true(all(class(plt_MGSG_det) == c("gg", "ggplot")))
-  expect_true(all(class(plt_MGSG_sto) == c("gg", "ggplot")))
+  expect_true(all(is_ggplot(plt_MGS)))
+  expect_true(all(is_ggplot(plt_MGS_det)))
+  expect_true(all(is_ggplot(plt_MGS_sto)))
+  expect_true(all(is_ggplot(plt_MGSG)))
+  expect_true(all(is_ggplot(plt_MGSG_det)))
+  expect_true(all(is_ggplot(plt_MGSG_sto)))
 })
\ No newline at end of file
