@@ -2,10 +2,14 @@ test_that("psrf",{
   # Very small fit to run super fast
   data("Male_Gammarus_Single")
   modelData_MGS <- modelData(Male_Gammarus_Single, time_accumulation = 4)
-  fit_MGS <- fitTK(modelData_MGS, iter = 10, chains = 2)
+  fit_MGS <- rmMessWarn(
+      fitTK(modelData_MGS, iter = 10, chains = 2, refresh = 0)
+  )
   data("Male_Gammarus_seanine_growth")
   modelData_MGSG <- modelData(Male_Gammarus_seanine_growth, time_accumulation = 1.417)
-  fit_MGSG <- fitTK(modelData_MGSG, iter = 10, chains=2)
+  fit_MGSG <- rmMessWarn(
+      fitTK(modelData_MGSG, iter = 10, chains=2, refresh = 0)
+  )
   
   psrf_MGS <- psrf(fit_MGS)
   psrf_MGSG <- psrf(fit_MGSG)
